@@ -23,6 +23,8 @@ SEXP OGR_write(SEXP inp)
 //  SEXP inp is an input list built in ogr_write() and documented
 //  in code there
 
+// poFeature->SetFID((long) INTEGER_POINTER(VECTOR_ELT(inp, 12))[i]) 130502
+
     OGRSFDriver *poDriver;
     OGRDataSource *poDS;
     OGRLayer *poLayer;
@@ -247,9 +249,13 @@ SEXP OGR_write(SEXP inp)
             if (z > 2) pt.setZ( NUMERIC_POINTER(crds)[i+(2*nobs)] );
 
             poFeature->SetGeometry( &pt ); 
+            if(poFeature->SetFID((long) INTEGER_POINTER(VECTOR_ELT(inp, 12))[i])  != OGRERR_NONE ) {
+               OGRDataSource::DestroyDataSource( poDS );
+               uninstallErrorHandlerAndTriggerError();
+               error( "Failed to set FID" );
+            } 
 
             if( poLayer->CreateFeature( poFeature ) != OGRERR_NONE ) {
-               installErrorHandler();
                OGRDataSource::DestroyDataSource( poDS );
                uninstallErrorHandlerAndTriggerError();
                error( "Failed to create feature" );
@@ -296,6 +302,13 @@ SEXP OGR_write(SEXP inp)
                error( "Failed to set geometry" );
             } 
 
+            if(poFeature->SetFID((long) INTEGER_POINTER(VECTOR_ELT(inp, 12))[i])  != OGRERR_NONE ) {
+               installErrorHandler();
+               OGRDataSource::DestroyDataSource( poDS );
+               uninstallErrorHandlerAndTriggerError();
+               error( "Failed to set FID" );
+            } 
+
             if( poLayer->CreateFeature( poFeature ) != OGRERR_NONE ) {
                installErrorHandler();
                OGRDataSource::DestroyDataSource( poDS );
@@ -361,6 +374,13 @@ SEXP OGR_write(SEXP inp)
                error( "Failed to set geometry" );
             } 
 
+            if(poFeature->SetFID((long) INTEGER_POINTER(VECTOR_ELT(inp, 12))[i])  != OGRERR_NONE ) {
+               installErrorHandler();
+               OGRDataSource::DestroyDataSource( poDS );
+               uninstallErrorHandlerAndTriggerError();
+               error( "Failed to set FID" );
+            } 
+
             if( poLayer->CreateFeature( poFeature ) != OGRERR_NONE ) {
                installErrorHandler();
                OGRDataSource::DestroyDataSource( poDS );
@@ -413,6 +433,13 @@ SEXP OGR_write(SEXP inp)
                error( "Failed to set geometry" );
             } 
 
+            if(poFeature->SetFID((long) INTEGER_POINTER(VECTOR_ELT(inp, 12))[i])  != OGRERR_NONE ) {
+               installErrorHandler();
+               OGRDataSource::DestroyDataSource( poDS );
+               uninstallErrorHandlerAndTriggerError();
+               error( "Failed to set FID" );
+            } 
+
             if( poLayer->CreateFeature( poFeature ) != OGRERR_NONE ) {
                installErrorHandler();
                OGRDataSource::DestroyDataSource( poDS );
@@ -475,6 +502,13 @@ SEXP OGR_write(SEXP inp)
                error( "Failed to set geometry" );
             } 
 
+            if(poFeature->SetFID((long) INTEGER_POINTER(VECTOR_ELT(inp, 12))[i])  != OGRERR_NONE ) {
+               installErrorHandler();
+               OGRDataSource::DestroyDataSource( poDS );
+               uninstallErrorHandlerAndTriggerError();
+               error( "Failed to set FID" );
+            } 
+
 	    // EJP:
 	    poFeature->SetGeometryDirectly(
 		OGRGeometryFactory::forceToMultiPolygon(
